@@ -22,7 +22,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 """
 
-__version__ = "0.3.35"
+__version__ = "0.3.36"
 __author__ = "nagev"
 __license__ = "GPLv3"
 
@@ -109,7 +109,7 @@ class g(object):
         '248': ('1920x1080', 'webm', 'normal', ''),
         '256': ('192k', 'm4a', 'audio', '6-channel'),
         '258': ('320k', 'm4a', 'audio', '6-channel'),
-        '264': ('1920x1080', 'm4v', 'video')
+        '264': ('1920x1080', 'm4v', 'video', '')
     }
 
 
@@ -463,6 +463,17 @@ class Pafy(object):
             self.gdata = g.opener.open(url).read()
         return self.gdata
 
+    @property
+    def published(self):
+        if not self._published:
+            t0 = "{http://www.w3.org/2005/Atom}"
+            gdata = self.get_video_gdata()
+            tree = etree.fromstring(gdata)
+            d = (tree.findall("%s%s" % (t0, "published")))
+            self._published = d[0].text.rstrip(".000Z").replace("T", " ")
+
+        return self._published
+
     @property
     def description(self):
         """ Extract description, fetch gdata if necessary. Return string."""
@@ -532,6 +543,7 @@ class Pafy(object):
         self.formats = f('fmt_list').split(",")
         self.formats = [x.split("/") for x in self.formats]
         self._description = None
+        self._published = None
         self._category = None
         self.keywords = self.bigthumb = self.bigthumbhd = None
         self.expires = int(time.time()) + (60 * 60 * 4)
